pub struct TreeNode<T> {
pub value: T,
}Expand description
A tree node that holds a value of type T generic
This structure represents a single node in a binary tree. It holds a value of type T and can
be compared to other TreeNodes based on the value it contains.
Fields
value: TThe value of this TreeNode
Implementations