pub struct Components { /* private fields */ }Expand description
The common components of an DSA keypair
(the prime p, quotient q and generator g)
Implementations
Sourceimpl Components
impl Components
Sourcepub fn from_components(p: BoxedUint, q: BoxedUint, g: BoxedUint) -> Result<Self>
pub fn from_components(p: BoxedUint, q: BoxedUint, g: BoxedUint) -> Result<Self>
Construct the common components container from its inner values (p, q and g)
Sourcepub fn from_components_unchecked(
p: BoxedUint,
q: BoxedUint,
g: BoxedUint,
) -> Result<Self>
pub fn from_components_unchecked( p: BoxedUint, q: BoxedUint, g: BoxedUint, ) -> Result<Self>
Construct the common components container from its inner values (p, q and g)
Safety
Any length of keys may be used, no checks are to be performed. You are responsible for checking the key strengths.