pub struct SigningKey { /* private fields */ }Expand description
DSA private key.
The (try_)sign_digest_with_rng API uses regular non-deterministic signatures,
while the (try_)sign_digest API uses deterministic signatures as described in RFC 6979
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn from_components(verifying_key: VerifyingKey, x: BigUint) -> Result<Self>
pub fn from_components(verifying_key: VerifyingKey, x: BigUint) -> Result<Self>
Construct a new private key from the public key and private component
Sourcepub fn generate(
rng: &mut impl CryptoRngCore,
components: Components,
) -> SigningKey
pub fn generate( rng: &mut impl CryptoRngCore, components: Components, ) -> SigningKey
Generate a new DSA keypair
Sourcepub const fn verifying_key(&self) -> &VerifyingKey
pub const fn verifying_key(&self) -> &VerifyingKey
DSA public key
Sourcepub fn x(&self) -> &BigUint
pub fn x(&self) -> &BigUint
DSA private component
If you decide to clone this value, please consider using Zeroize::zeroize to zero out the memory after you’re done using the clone
Sourcepub fn sign_prehashed_rfc6979<D>(
&self,
prehash: &[u8],
) -> Result<Signature, Error>where
D: Digest + BlockSizeUser + FixedOutputReset,
pub fn sign_prehashed_rfc6979<D>(
&self,
prehash: &[u8],
) -> Result<Signature, Error>where
D: Digest + BlockSizeUser + FixedOutputReset,
Try to sign the given message digest deterministically with a prehashed digest.
The parameter D must match the hash function used to sign the digest.